@@ -72,32 +72,22 @@
 <context>
     <name>DialogDBStat</name>
     <message>
-        <location filename="DialogDBStatistics.py" line="96"/>
+        <location filename="DialogDBStatistics.py" line="99"/>
         <source>QNetMan (Database statistics)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogDBStatistics.py" line="97"/>
+        <location filename="DialogDBStatistics.py" line="100"/>
         <source>Database file size:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogDBStatistics.py" line="98"/>
-        <source>0000 KB</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogDBStatistics.py" line="99"/>
+        <location filename="DialogDBStatistics.py" line="101"/>
         <source>Table traffic statistics:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="DialogDBStatistics.py" line="102"/>
-        <source>000000 records</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogDBStatistics.py" line="101"/>
         <source>Table sessions statistics:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -171,67 +161,67 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="224"/>
+        <location filename="DialogOptionsIfaceExt.py" line="227"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="92"/>
+        <location filename="DialogOptionsIfaceExt.py" line="95"/>
         <source>Specified network interface already exists</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="108"/>
+        <location filename="DialogOptionsIfaceExt.py" line="111"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="109"/>
+        <location filename="DialogOptionsIfaceExt.py" line="112"/>
         <source>Error to the database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="113"/>
+        <location filename="DialogOptionsIfaceExt.py" line="116"/>
         <source>You can not delete all the network interfaces</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="185"/>
+        <location filename="DialogOptionsIfaceExt.py" line="188"/>
         <source>Disable</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="192"/>
+        <location filename="DialogOptionsIfaceExt.py" line="195"/>
         <source>Enable</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="206"/>
+        <location filename="DialogOptionsIfaceExt.py" line="209"/>
         <source>Before you disable/delete the network interface, turn off the record on this network interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="225"/>
+        <location filename="DialogOptionsIfaceExt.py" line="228"/>
         <source>Should be left on at least one network interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="246"/>
+        <location filename="DialogOptionsIfaceExt.py" line="249"/>
         <source>MAC address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="247"/>
+        <location filename="DialogOptionsIfaceExt.py" line="250"/>
         <source>RX bytes/RX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="248"/>
+        <location filename="DialogOptionsIfaceExt.py" line="251"/>
         <source>TX bytes/TX packets</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogOptionsIfaceExt.py" line="138"/>
+        <location filename="DialogOptionsIfaceExt.py" line="141"/>
         <source>Network interface cannot be deleted when the database has recorded net session at the interface</source>
         <translation type="unfinished"></translation>
     </message>
@@ -272,18 +262,12 @@
 <context>
     <name>DialogRecordManager</name>
     <message>
-        <location filename="DialogRecordData.py" line="56"/>
+        <location filename="DialogRecordData.py" line="45"/>
         <source>Record</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogRecordData.py" line="57"/>
-        <source>Auto
-record</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogRecordData.py" line="55"/>
+        <location filename="DialogRecordData.py" line="44"/>
         <source>QNetMan (Data record)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -357,33 +341,28 @@ record</source>
 <context>
     <name>ListSessions</name>
     <message>
-        <location filename="ListSessions.py" line="94"/>
+        <location filename="ListSessions.py" line="95"/>
         <source>QNetMan (Networking sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="95"/>
+        <location filename="ListSessions.py" line="96"/>
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="96"/>
+        <location filename="ListSessions.py" line="97"/>
         <source>Filter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="97"/>
+        <location filename="ListSessions.py" line="98"/>
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="ListSessions.py" line="98"/>
-        <source>Delete</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="ListSessions.py" line="99"/>
-        <source>Menu</source>
+        <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -410,105 +389,100 @@ record</source>
 <context>
     <name>ListSessionsExt</name>
     <message>
-        <location filename="ListSessionsExt.py" line="111"/>
+        <location filename="ListSessionsExt.py" line="230"/>
         <source>Deleting sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="112"/>
+        <location filename="ListSessionsExt.py" line="231"/>
         <source>Delete selected sessions ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="164"/>
+        <location filename="ListSessionsExt.py" line="283"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="262"/>
+        <location filename="ListSessionsExt.py" line="400"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="263"/>
+        <location filename="ListSessionsExt.py" line="401"/>
         <source>Session does not contain data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="320"/>
+        <location filename="ListSessionsExt.py" line="458"/>
         <source>records</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="132"/>
+        <location filename="ListSessionsExt.py" line="251"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="133"/>
+        <location filename="ListSessionsExt.py" line="252"/>
         <source>Sorry, an error in the database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="358"/>
+        <location filename="ListSessionsExt.py" line="496"/>
         <source>Select a session to calculate the traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="363"/>
+        <location filename="ListSessionsExt.py" line="501"/>
         <source>Sessions:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="366"/>
+        <location filename="ListSessionsExt.py" line="504"/>
         <source>Full traffic:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="364"/>
+        <location filename="ListSessionsExt.py" line="502"/>
         <source>RX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="365"/>
+        <location filename="ListSessionsExt.py" line="503"/>
         <source>TX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="55"/>
-        <source>Loading...</source>
+        <location filename="ListSessionsExt.py" line="309"/>
+        <source>Please, wait...</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="MainWindow.py" line="81"/>
+        <location filename="MainWindow.py" line="82"/>
         <source>QNetMan (QNetworkManager)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="82"/>
+        <location filename="MainWindow.py" line="83"/>
         <source>Network
 sessions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="86"/>
+        <location filename="MainWindow.py" line="87"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="87"/>
+        <location filename="MainWindow.py" line="88"/>
         <source>Network
 connections</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="ViewSession.py" line="240"/>
-        <source>Menu</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="MainWindow.py" line="90"/>
         <source>About</source>
@@ -670,187 +644,103 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WindowFilterOptions.py" line="125"/>
-        <source>gprs0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WindowFilterOptions.py" line="126"/>
-        <source>wlan0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WindowFilterOptions.py" line="128"/>
-        <source>usb0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WindowFilterOptions.py" line="129"/>
-        <source>eth0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WindowFilterOptions.py" line="127"/>
-        <source>pan0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewSession.py" line="219"/>
+        <location filename="ViewSession.py" line="226"/>
         <source>QNetMan (Sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="220"/>
+        <location filename="ViewSession.py" line="227"/>
         <source>Session start time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="221"/>
+        <location filename="ViewSession.py" line="228"/>
         <source>Session end time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="223"/>
-        <source>2000-01-01 00:00:00</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewSession.py" line="232"/>
+        <location filename="ViewSession.py" line="233"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="227"/>
-        <source>0000.00 MB</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewSession.py" line="233"/>
+        <location filename="ViewSession.py" line="234"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="228"/>
+        <location filename="ViewSession.py" line="231"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="229"/>
-        <source>00 h; 00 m; 00 s</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewSession.py" line="230"/>
+        <location filename="ViewSession.py" line="232"/>
         <source>Full session traffic :</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="ViewSession.py" line="231"/>
-        <source>000000 MB</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="ViewSession.py" line="241"/>
         <source>Remove session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="91"/>
+        <location filename="WinAbout.py" line="100"/>
         <source>QNetMan (About)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="92"/>
-        <source>QNetworkManager</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinAbout.py" line="93"/>
+        <location filename="WinAbout.py" line="101"/>
         <source>Version:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="95"/>
+        <location filename="WinAbout.py" line="102"/>
         <source>Author:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="96"/>
-        <source>Kozlov Anatoliy</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinAbout.py" line="97"/>
-        <source>&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinAbout.py" line="98"/>
-        <source>&lt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WinAbout.py" line="99"/>
+        <location filename="WinAbout.py" line="104"/>
         <source>Homepage:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="100"/>
-        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
-&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Microsoft Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qnetman.garage.maemo.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://qnetman.garage.maemo.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WindowFilterOptions.py" line="120"/>
+        <location filename="WindowFilterOptions.py" line="96"/>
         <source>QNetMan (Session filters)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WindowFilterOptions.py" line="121"/>
+        <location filename="WindowFilterOptions.py" line="97"/>
         <source>Apply</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WindowFilterOptions.py" line="124"/>
-        <source>All</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="WindowFilterOptions.py" line="131"/>
+        <location filename="WindowFilterOptions.py" line="98"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WindowFilterOptions.py" line="132"/>
+        <location filename="WindowFilterOptions.py" line="99"/>
         <source>Session start time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WindowFilterOptions.py" line="133"/>
+        <location filename="WindowFilterOptions.py" line="100"/>
         <source>Session end time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.py" line="84"/>
+        <location filename="MainWindow.py" line="85"/>
         <source>Monitor 
 connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="238"/>
+        <location filename="ViewSession.py" line="239"/>
         <source>000 kB/s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAbout.py" line="94"/>
-        <source>0.4.0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewSession.py" line="239"/>
+        <location filename="ViewSession.py" line="240"/>
         <source>Please, wait ...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -869,6 +759,11 @@ connections</source>
         <source>Network interfaces</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinAbout.py" line="103"/>
+        <source>Anatoliy Kozlov</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowExt</name>
@@ -912,58 +807,23 @@ Start daemons now ?</source>
 <context>
     <name>ViewCurrentSession</name>
     <message>
-        <location filename="ViewCurrentSession.py" line="173"/>
+        <location filename="ViewCurrentSession.py" line="184"/>
         <source>QNetMan (Monitor)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="186"/>
+        <location filename="ViewCurrentSession.py" line="187"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSession.py" line="176"/>
-        <source>000.00 MB</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="187"/>
+        <location filename="ViewCurrentSession.py" line="188"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="179"/>
-        <source>V</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="181"/>
-        <source>000.00 MB/s</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="182"/>
-        <source>rx</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="183"/>
-        <source>tx</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="184"/>
-        <source>Interval:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="ViewCurrentSession.py" line="185"/>
-        <source>2 sec</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="ViewCurrentSession.py" line="188"/>
-        <source>Options</source>
+        <source>Interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -976,6 +836,11 @@ Start daemons now ?</source>
         <source>Network interface</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ViewCurrentSession.py" line="186"/>
+        <source>2 sec</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewCurrentSessionExt</name>
@@ -1036,45 +901,50 @@ Start daemons now ?</source>
 <context>
     <name>WinAboutExt</name>
     <message>
-        <location filename="WinAboutExt.py" line="131"/>
+        <location filename="WinAboutExt.py" line="141"/>
         <source>Thanks:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="144"/>
+        <location filename="WinAboutExt.py" line="156"/>
         <source>Licence:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="145"/>
+        <location filename="WinAboutExt.py" line="157"/>
         <source>GPL v2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="133"/>
+        <location filename="WinAboutExt.py" line="143"/>
         <source>Used icon set &quot;Crystal-clear&quot; by Everaldo Coelho</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="122"/>
+        <location filename="WinAboutExt.py" line="132"/>
         <source>Qt-based network manager which allows to monitor your network traffic. It is possible to record network sessions information for different connections and provide the information in graphical view.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="132"/>
+        <location filename="WinAboutExt.py" line="142"/>
         <source>Vladimir Sinichkin - for translation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="146"/>
+        <location filename="WinAboutExt.py" line="158"/>
         <source>Donate:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinAboutExt.py" line="147"/>
+        <location filename="WinAboutExt.py" line="159"/>
         <source>You can donate to project via PayPal to qnetworkmanager@gmail.com</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="WinAboutExt.py" line="144"/>
+        <source>Krisztian Olah - for testing and good ideas</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WinNetStat</name>
@@ -1107,82 +977,82 @@ Start daemons now ?</source>
 <context>
     <name>WinNetStatProcExt</name>
     <message>
-        <location filename="WinNetStatProcExt.py" line="374"/>
+        <location filename="WinNetStatProcExt.py" line="377"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="375"/>
+        <location filename="WinNetStatProcExt.py" line="378"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="388"/>
+        <location filename="WinNetStatProcExt.py" line="391"/>
         <source>Please, wait...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="404"/>
+        <location filename="WinNetStatProcExt.py" line="407"/>
         <source>Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="415"/>
+        <location filename="WinNetStatProcExt.py" line="418"/>
         <source>Back</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="456"/>
+        <location filename="WinNetStatProcExt.py" line="459"/>
         <source>The device has received a connection request and send the acknowledgment. At the moment, is expected to start the connection.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="459"/>
+        <location filename="WinNetStatProcExt.py" line="462"/>
         <source>The &quot;steady state&quot; of an open TCP connection. Data can be exchanged freely once both devices in the connection enter this state. This will continue until the connection is closed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="346"/>
+        <location filename="WinNetStatProcExt.py" line="349"/>
         <source>Information is not available</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="448"/>
+        <location filename="WinNetStatProcExt.py" line="451"/>
         <source>Device (normally a server) is waiting for client connection</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="453"/>
+        <location filename="WinNetStatProcExt.py" line="456"/>
         <source>Device (normally a client) sent a request to connect to another device and is waiting for confirmation (normally from a server).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="462"/>
+        <location filename="WinNetStatProcExt.py" line="465"/>
         <source>One of the stages of closing the connection. Connection closing sent the request to the remote device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="465"/>
+        <location filename="WinNetStatProcExt.py" line="468"/>
         <source>The last stage of closing the connection. Connection closing sent the request to the remote device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="471"/>
+        <location filename="WinNetStatProcExt.py" line="474"/>
         <source>One of the stages of closing the connection. Connection closing sent the request to the local device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="480"/>
+        <location filename="WinNetStatProcExt.py" line="483"/>
         <source>This is the state by default before the connection is established. This is the sitation when there is no any connection between devices : it eather hasn&apos;t been created yet, or has just been broken.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="474"/>
+        <location filename="WinNetStatProcExt.py" line="477"/>
         <source>One of the stages of closing the connection. The simultaneous closure of the connection.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="WinNetStatProcExt.py" line="477"/>
+        <location filename="WinNetStatProcExt.py" line="480"/>
         <source>The last stage of closing the connection. After wait period, the connection pass to the CLOSED state.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1190,37 +1060,17 @@ Start daemons now ?</source>
 <context>
     <name>dlgNetworkSelect</name>
     <message>
-        <location filename="DialogNetworkIface.py" line="59"/>
+        <location filename="DialogNetworkIface.py" line="57"/>
         <source>QNetMan (Select network interface)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogNetworkIface.py" line="62"/>
-        <source>gprs0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogNetworkIface.py" line="63"/>
-        <source>wlan0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogNetworkIface.py" line="64"/>
-        <source>lo</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogNetworkIface.py" line="66"/>
-        <source>iface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="DialogNetworkIface.py" line="67"/>
+        <location filename="DialogNetworkIface.py" line="58"/>
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="DialogNetworkIface.py" line="68"/>
+        <location filename="DialogNetworkIface.py" line="59"/>
         <source>Select the network interface
  for monitoring</source>
         <translation type="unfinished"></translation>
