@@ -37,7 +37,7 @@ class DialogRecordManagerExt(Ui_DialogRecordManager, QtCore.QObject):
 			self.lWIface.addItem( item )
 
 		self.pbRecStartStop.setEnabled( False )
-		self.pbAutoRecOnOff.hide()
+		#self.pbAutoRecOnOff.hide()
 		
 		self.lWIface.itemClicked.connect( self.clickedItem )
 		self.pbRecStartStop.toggled.connect( self.recStartStop )
