@@ -28,7 +28,7 @@ class WinAboutExt( QtGui.QMainWindow ):
 		self.createSlidingStackedWidget()
 
 		#XXX# Версия программы #XXX#
-		self.ui.lblVersionVal.setText("0.7.0")
+		self.ui.lblVersionVal.setText("0.7.4")
 
 		self.actionForm()
 
@@ -48,6 +48,16 @@ class WinAboutExt( QtGui.QMainWindow ):
 		self.setContentP1()
 		self.setContentP2()
 		self.setContentP3()
+			
+		icon = QtGui.QIcon()
+		icon.addPixmap(QtGui.QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_forward.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+		self.ui.pb_nextA.setIcon(icon)
+		self.ui.pb_nextA.setText("")
+		
+		icon = QtGui.QIcon()
+		icon.addPixmap(QtGui.QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_back.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+		self.ui.pb_prevA.setIcon(icon)
+		self.ui.pb_prevA.setText("")
 
 
 	def openBrowser(self):
@@ -131,10 +141,12 @@ class WinAboutExt( QtGui.QMainWindow ):
 		txt1 = QtGui.QApplication.translate("WinAboutExt", "Thanks:", None, QtGui.QApplication.UnicodeUTF8)
 		txt2 = QtGui.QApplication.translate("WinAboutExt", "Vladimir Sinichkin - for translation", None, QtGui.QApplication.UnicodeUTF8)
 		txt3 = QtGui.QApplication.translate("WinAboutExt", "Used icon set \"Crystal-clear\" by Everaldo Coelho", None, QtGui.QApplication.UnicodeUTF8)
+		txt4 = QtGui.QApplication.translate("WinAboutExt", "Krisztian Olah - for testing and good ideas", None, QtGui.QApplication.UnicodeUTF8)
 		str  = "<html>"
 		str += "<div style='font-size: 14pt;'>"
 		str += "<p>%s</p>"%txt1
 		str += "%s<br/>"%txt2
+		str += "%s<br/>"%txt4
 		str += "%s<br/>"%txt3
 		str += "</div>"
 		str += "</html>"
