@@ -2,12 +2,12 @@
 # -*- coding: utf-8 -*-
 
 qnetman_home="/home/user/.qnetman/"
-#qnetman_home = "/home/user/develop/qnetman/"
 
 qnetman_path = "/opt/qnetman/"
-#qnetman_path = "/home/user/develop/qnetman/"
 
 file_db = qnetman_home + "qnetman.db"
 
+file_setting = qnetman_home + "qnetman.conf"
+
 i18n_rus = qnetman_path + "i18n/qnetman_rus.qm"
 
